@@ -19,7 +19,7 @@ use pyo3::types::{PyString, PyTuple};
 /// :param attribute_filter: Allows rewriting of all attributes using a callback.
 ///     The callback takes name of the element, attribute and its value.
 ///     Returns ``None`` to remove the attribute, or a value to use.
-/// :type attribute_filter: ``Callable[[str, str, str], str]``, optional
+/// :type attribute_filter: ``Callable[[str, str, str], str | None]``, optional
 /// :param strip_comments: Configures the handling of HTML comments, defaults to ``True``.
 /// :type strip_comments: ``bool``
 /// :param link_rel: Configures a ``rel`` attribute that will be added on links, defaults to ``noopener noreferrer``.
@@ -110,7 +110,17 @@ fn clean(
                             }
                             Err(err) => err,
                         };
-                        err.restore(py);
+                        err.write_unraisable(
+                            py,
+                            Some(PyTuple::new(
+                                py,
+                                [
+                                    PyString::new(py, element),
+                                    PyString::new(py, attribute),
+                                    PyString::new(py, value),
+                                ],
+                            )),
+                        );
                         Some(value.into())
                     })
                 });
@@ -155,7 +165,7 @@ fn is_html(py: Python, html: &str) -> bool {
     py.allow_threads(|| ammonia::is_html(html))
 }
 
-/// Python binding to the ammonia HTML sanitizer crate
+/// Python binding to the `ammonia <https://github.com/rust-ammonia/ammonia>`_ HTML sanitizer Rust crate.
 #[pymodule]
 fn nh3(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add("__version__", env!("CARGO_PKG_VERSION"))?;
